@@ -8,7 +8,7 @@
 
 """
 Notes:
-    this some of this part are a copy from sympy
+    These are some of parts coped from sympy.
 """
 
 from __future__ import division
@@ -122,16 +122,23 @@ class Dim(numeric.ndarray):
     """Redefine the Dimension of sympy, the default dimension SI system with 7 number.\n
     1.can be constructed by list of number.\n
     2.can be translated from a sympy.physics.unit. \n
-        # >>>from sympy.physics.units import N
-        # >>>scale,dim = Dim.convert_to_Dim(N)
-        #inverse back
-    """
-    """
-    #     self.unit = [str(i) for i in SI._base_units]\n
-    #     self.unit_map = {'meter': "m", 'kilogram': "kg", 'second': "s",
-    #     'ampere': "A", 'mole': "mol", 'candela': "cd", 'kelvin': "K"}\n
-    #     self.dim = ['length', 'mass', 'time', 'current', 'amount_of_substance',
-    #     'luminous_intensity', 'temperature']
+
+    Examples::
+
+        from sympy.physics.units import N
+        scale,dim = Dim.convert_to_Dim(N)
+
+    Examples::
+
+        dim=[1,0,1,0,1,0,0]
+        dim = Dim(dim)
+
+    Notes:
+        self.unit = [str(i) for i in SI._base_units]\n
+        self.unit_map = {'meter': "m", 'kilogram': "kg", 'second': "s",
+        'ampere': "A", 'mole': "mol", 'candela': "cd", 'kelvin': "K"}\n
+        self.dim = ['length', 'mass', 'time', 'current', 'amount_of_substance',
+        'luminous_intensity', 'temperature']
     """
 
     def __new__(cls, data):
@@ -361,18 +368,15 @@ class Dim(numeric.ndarray):
     def convert_to_Dim(cls, u, target_units=None, unit_system="SI"):
         """
         depend on sympy 1.5-1.6!!!
+
         Parameters
         ----------
-        u: sympy.physics.unit or Expr of sympy.physics.unit
+        u: sympy.physics.unit, Expr of sympy.physics.unit
             unit.
-        target_units: None or list of sympy.physics.unit
+        target_units: None, list of sympy.physics.unit
             if None, the target_units is 7 SI units
         unit_system: str
             default is unit_system="SI"
-            
-        Returns
-        -------
-        Expr
         """
         if isinstance(u, Dim):
             return 1, u
@@ -385,8 +389,8 @@ class Dim(numeric.ndarray):
         """
         depend on sympy 1.5-1.6!!!
         Quick method. translate xi and ui to standard system.
+
         Parameters
-        
         ----------
         xi: np.ndarray
             xi
@@ -399,11 +403,9 @@ class Dim(numeric.ndarray):
 
         Returns
         -------
-        xi: 
-            np.ndarray
-        
-        expr: 
-            Expr
+        xi: np.ndarray
+
+        expr: Expr
         """
         expr_scale_factor, d = cls.convert_to_Dim(ui, target_units=target_units, unit_system=unit_system)
         xi = expr_scale_factor * xi
@@ -414,7 +416,7 @@ class Dim(numeric.ndarray):
     @classmethod
     def convert_x(cls, x, u, target_units=None, unit_system="SI"):
         """
-        depend on sympy 1.5-1.6!!!
+         depend on sympy 1.5-1.6!!!
          Quick method. translate x and u to standard system.
          
          Parameters
@@ -430,11 +432,8 @@ class Dim(numeric.ndarray):
 
          Returns
          -------
-         x: 
-             np.ndarray
-         
-         expr: 
-             Expr
+         x: np.ndarray
+         expr: Expr
          
          """
         if isinstance(x, list):
@@ -453,8 +452,8 @@ class Dim(numeric.ndarray):
         """
         depend on sympy 1.5-1.6!!!
         Quick method. Translate ui to other unit.
+
         Parameters
-        
         ----------
         dim: Dim
             dim
@@ -467,11 +466,9 @@ class Dim(numeric.ndarray):
 
         Returns
         -------
-        scale: 
-            float
-        
-        expr: 
-            Expr
+        scale:float
+
+        expr: Expr
         """
         from sympy.physics.units import UnitSystem
         unit_system = UnitSystem.get_unit_system(unit_system)
@@ -502,8 +499,8 @@ class Dim(numeric.ndarray):
         """
         depend on sympy 1.5-1.6!!!
         Quick method. Translate xi, dim to other unit.
+
         Parameters
-        
         ----------
         xi:np.ndarray
             xi
@@ -518,10 +515,9 @@ class Dim(numeric.ndarray):
 
         Returns
         -------
-        scale: 
-            float
-        expr: 
-            Expr
+        scale: float
+
+        expr: Expr
         """
         expr_scale_factor, d = cls.inverse_convert(dim, scale=scale, target_units=target_units, unit_system=unit_system)
         xi = expr_scale_factor * xi
